'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const handleHerfParams = new URL(location.href).searchParams;

class Request {
    /**
     * 设置公共参数
     * @param publicParams an url as a string
     */
    setPublicParams(publicParams) {
        Request.publicParams = Object.assign(Object.assign({}, Request.publicParams), publicParams);
    }
    /**
     * 删除公共参数的某一项
     * @param key an url as a string
     */
    removePublicParams(key) {
        delete Request.publicParams[key];
    }
    /**
     * 设置响应拦截器
     */
    setResponseIntercept(callback) {
        Request.responseIntercept = callback;
    }
    /**
     * 捕获异常处理
     */
    setErrorCallback(callback) {
        Request.errorCallback = callback;
    }
    /**
     * 请求之前干点啥
     */
    setRequestBefore(callback) {
        Request.requestBefore = callback;
    }
    /**
     * 设置请求头
     */
    setHeaders(headers) {
        Request.Headers = headers;
    }
}
Request.publicParams = {};
Request.Headers = {};

const appid = 'miaojie';
function getConfig(env) {
    const config = {
        baseUrl: 'https://hserver.moxigame.cn/istio/grpc-gate/',
        encode: false,
    };
    switch (env) {
        case 'dev': // 开发
            config.baseUrl = 'https://k8s-dev.moxigame.top/istio/grpc-gate/';
            config.encode = false;
            break;
        case 'test': // 测试
            config.baseUrl = 'https://sandbox.platform.moxigame.cn/k8s-test/istio/grpc-gate/';
            config.encode = false;
            break;
        case 'pre': // 预发
            config.baseUrl = 'https://sandbox.platform.moxigame.cn/k8s-pre/istio/grpc-gate/';
            config.encode = false;
            break;
    }
    return config;
}
(function (EMX_TaskGroup) {
    /** 常规任务组 */
    EMX_TaskGroup[EMX_TaskGroup["TASK"] = 1] = "TASK";
    /** 成就任务组 */
    EMX_TaskGroup[EMX_TaskGroup["ACHIEVEMENT"] = 2] = "ACHIEVEMENT";
    /** 终极大奖成就任务 */
    EMX_TaskGroup[EMX_TaskGroup["FINALAWARDTASK"] = 3] = "FINALAWARDTASK";
})(exports.EMX_TaskGroup || (exports.EMX_TaskGroup = {}));

class TaskApi {
    /** 用户任务列表
     * @param {string} data.groupId 任务分组 1=普通任务；2=成就任务；3=终极大奖成就任务
     * @returns 返回任务列表数据
     */
    getList(data) {
        return Request.channelHttp.http({ url: '/task/user/v1/list', data });
    }
    /** 完成任务领取奖励
     * @param {string} data.taskId 任务ID
     */
    getAwards(data) {
        return Request.channelHttp.http({ url: '/task/user/v1/finishTask', data });
    }
    /** 做任务
     * @param {string} data.opType      任务操作类型 set/add/max
     * @param {number} data.opValue     任务操作值
     * @param {string} data.taskId      任务id
     * @param {string} data.judgeValue  区分相同类型任务
     * @param {string} data.groupId     任务分组 1=普通任务；2=成就任务；3=终极大奖成就任务
     * @param {string} data.adId        完成任务相关的广告id
     */
    doEvent(data) {
        return Request.channelHttp.http({ url: '/task/user/v1/doEventTask', data });
    }
}

class Task extends TaskApi {
    constructor() {
        super();
    }
}
const task = new Task();

class ChannelApi {
    /** 生成短链接
     * @param {string} data.longUrl
     */
    gen(data) {
        return Request.channelHttp.http({ url: '/channel/user/v1/shorturl/gen', data });
    }
    /** 解析短链接
     * @param {string} data.hashcode 短链接hashcode
     */
    get(data) {
        return Request.channelHttp.http({ url: '/channel/user/v1/shorturl/get', data });
    }
    /** 渠道订单能力，提供第三方订单查询能力
     * @param {RequestOrderType} data
     */
    getOrderList(data) {
        return Request.channelHttp.http({ url: '/channel/user/v1/order/list', data });
    }
}

class Channel extends ChannelApi {
    constructor() {
        super();
    }
}
const channel = new Channel();

class BenefitApi {
    /** C 端查询用户获得的奖励
     * @param {string} data.sId codeId （可以使用sCode单独查询）
     */
    getList(data) {
        return Request.channelHttp.http({ url: '/benefit/user/v1/queryuserlist', data });
    }
    /** 用户填写地址
     * @param {IMX_InputUserAddrInfo} data 地址信息
     */
    fillAddr(data) {
        return Request.channelHttp.http({ url: '/benefit/user/v1/filladdr', data });
    }
    /** 填写直充账号
     * @param {string} data.account 用户直充账号
     */
    fillAccount(data) {
        return Request.channelHttp.http({ url: '/benefit/user/v1/fillAccount', data });
    }
    /** 失效奖励,1.先不关注返还第三方的,2.总量加一
     * @param {string} data.sId
     */
    usedCode(data) {
        return Request.channelHttp.http({ url: '/benefit/user/v1/usedcode', data: { sId: data.sId, eSuccess: "succ", } });
    }
}

class Benefit extends BenefitApi {
    constructor() {
        super();
    }
}
const benefit = new Benefit();

class ActiveApi {
    /** 查询活动的基本信息 */
    getDetails() {
        return Request.channelHttp.http({ url: '/active/user/v1/get' });
    }
}

class Active extends ActiveApi {
    constructor() {
        super();
    }
}
const active = new Active();

class Additional extends ActiveApi {
    constructor() {
        super();
    }
}
const additional = new Additional();

class AdvertApi {
    /** 获取当前活动下的 广告投放 配置信息
     * @param data.eStatus 当前营销能力状态  unknow: 未知 - running: 投放中 - finish: 已结束 - wait: 待投放 - pause: 取消投放
     * @param data.sId 投放组id
     * @param data.sPos 投放位置
     * @param data.iBeginTime 开始时间
     * @param data.iEndTime 结束时间
     * @param data.page 所处页面数
     * @param data.pageSize 单页数据条数
     */
    getList(data) {
        return Request.channelHttp.http({ url: '/advert/user/v1/output/list', data });
    }
}

class Advert extends AdvertApi {
    constructor() {
        super();
    }
}
const advert = new Advert();

class FragmentApi {
    /** 集卡/拼图 领奖
     * @param data.settingId: 玩法配置id
     * @param data.id: 集字玩法 - 需要传入需要领取的 奖励主键id   拼图不需要
     * @param data.items 集字玩法 使用任意类型碎片兑换 , 需要传此参数 含 itemId itemCount
    */
    getAwards(data) {
        return Request.channelHttp.http({ url: '/fragment/user/v1/getAwards', data: Object.assign(Object.assign({}, data), { userId: Request.channelHttp.getUserId() }) });
    }
    /** 集卡/拼图 列表
     * @param data.showLocation: 展示位置
    */
    getList(data) {
        return Request.channelHttp.http({ url: '/fragment/user/v1/userAwardList', data: Object.assign(Object.assign({}, data), { userId: Request.channelHttp.getUserId() }) });
    }
}

class Fragment extends FragmentApi {
    constructor() {
        super();
    }
}
const fragment = new Fragment();

class FriendApi {
    /** 好友系统 添加到黑名单
     * @param data.targetId 需要拉黑的目标用户id
     */
    addBlacklist(data) {
        return Request.channelHttp.http({ url: '/friends/user/v1/addBlacklist', data: Object.assign(Object.assign({}, data), { gameId: Request.channelHttp.getUserId() }) });
    }
    /** 好友系统 通过ID请求添加好友
     * @param data.targetId 需要申请好友的目标用户id
     */
    addFriendApply(data) {
        return Request.channelHttp.http({ url: '/friends/user/v1/addFriendApply', data: Object.assign(Object.assign({}, data), { gameId: Request.channelHttp.getUserId() }) });
    }
    /** 好友系统 处理好友申请请求
     * @param data.targetId 处理好友申请请求 的目标用户id
     * @param data.agree 是否同意好友请求
     */
    dealFriendApply(data) {
        return Request.channelHttp.http({ url: '/friends/user/v1/dealFriendApply', data: Object.assign(Object.assign({}, data), { gameId: Request.channelHttp.getUserId() }) });
    }
    /** 好友系统 从黑名单中移出
     * @param data.targetId 目标用户id
     */
    deleteBlacklist(data) {
        return Request.channelHttp.http({ url: '/friends/user/v1/deleteBlacklist', data: Object.assign(Object.assign({}, data), { gameId: Request.channelHttp.getUserId() }) });
    }
    /** 好友系统 删除好友
     * @param data.targetId 目标用户id
     */
    deleteFriend(data) {
        return Request.channelHttp.http({ url: '/friends/user/v1/deleteFriend', data: Object.assign(Object.assign({}, data), { gameId: Request.channelHttp.getUserId() }) });
    }
    /** 好友系统 通过id查询个人详细信息
     * @param data.targetId 目标用户id
     */
    getPlayerInfo(data) {
        return Request.channelHttp.http({ url: '/friends/user/v1/getPlayerInfo', data: Object.assign(Object.assign({}, data), { gameId: Request.channelHttp.getUserId() }) });
    }
    /** 好友系统 获取黑名单列表 */
    getBlackList() {
        return Request.channelHttp.http({ url: '/friends/user/v1/queryBlacklist', data: { gameId: Request.channelHttp.getUserId() } });
    }
    /** 好友系统 获取好友申请列表 */
    getFriendsList() {
        return Request.channelHttp.http({ url: '/friends/user/v1/queryFriends', data: { gameId: Request.channelHttp.getUserId() } });
    }
    /** 好友系统 获取随机推举好友
     * @param data.num 目标用户id
     * @param data.preList 上次推举的好友id数组
     */
    getRecommendFriends(data) {
        return Request.channelHttp.http({ url: '/friends/user/v1/randomRecommend', data: Object.assign(Object.assign({}, data), { gameId: Request.channelHttp.getUserId() }) });
    }
    /** 好友系统 生成好友申请key (生成名片)  */
    buildBusinessCard() {
        return Request.channelHttp.http({ url: '/friends/user/v1/buildBusinessCard', data: { gameId: Request.channelHttp.getUserId() } });
    }
    /** 好友系统 使用好友key (使用名片)
     * @param data.card 发送用户的名片
     */
    useBusinessCard(data) {
        return Request.channelHttp.http({ url: '/friends/user/v1/useBusinessCard', data: Object.assign({ gameId: Request.channelHttp.getUserId() }, data) });
    }
    /** 更新个人信息  一般C端不需要调用此接口 由游戏服更新  */
    updatePlayerInfo(data) {
        return Request.channelHttp.http({ url: '/friends/user/v1/updatePlayerInfo', data: Object.assign(Object.assign({}, data), { gameId: Request.channelHttp.getUserId() }) });
    }
}

class Friend extends FriendApi {
    constructor() {
        super();
    }
}
const friend = new Friend();

class ItemApi {
    /** 获取游戏道具背包信息
     * @param data.sItemId: 道具id
     * @param data.bShow: 是否返回显示资源 默认不显示
     * @param data.bScore: 是否三方积分查询
    */
    getList(data) {
        return Request.channelHttp.http({ url: '/item/user/v1/userItemList', data: Object.assign(Object.assign({}, data), { sUserId: Request.channelHttp.getUserId() }) });
    }
    /** 使用游戏道具
     * @param data.sItemId: 道具id
     * @param data.iCount: 使用道具数量
     * @param data.items 集字玩法 使用任意类型碎片兑换 , 需要传此参数 含 itemId itemCount
    */
    useItem(data) {
        return Request.channelHttp.http({ url: '/item/user/v1/useItem', data: Object.assign(Object.assign({}, data), { sUserId: Request.channelHttp.getUserId() }) });
    }
    /** 移动两个用户道具
     * @param data.sTargetUid: 目标用户ID
     * @param data.sTargetActiveId: 目标活动ID
     * @param data.sSourceUid 来源用户ID
     * @param data.sSourceActiveId 来源活动ID
     * @param data.mInfo 移动道具信息
    */
    move(data) {
        return Request.channelHttp.http({ url: '/item/user/v1/moveUserItem', data });
    }
}

class Item extends ItemApi {
    constructor() {
        super();
    }
}
const item = new Item();

class LuckyDraw extends ItemApi {
    constructor() {
        super();
    }
}
const luckyDraw = new LuckyDraw();

class MailUserApi {
    /** 获取邮件列表
     * @param {number} data.page 当前页面数
     * @param {number} data.pageSize 单页条数
     */
    getList(data) {
        return Request.channelHttp.http({ url: '/mail/user/v1/mails:list', data: Object.assign(Object.assign({}, data), { userId: Request.channelHttp.getUserId() }) });
    }
    /** 读取邮件详情
     * @param {string} data.mailId
     */
    getDetail(data) {
        return Request.channelHttp.http({ url: '/mail/user/v1/mails:get', data: Object.assign(Object.assign({}, data), { userId: Request.channelHttp.getUserId() }) });
    }
    /** 通过邮件id删除邮件
     * @param data.mailId
     */
    deleteByMailIds(data) {
        return Request.channelHttp.http({ url: '/mail/user/v1/mails:batch_delete', data: Object.assign(Object.assign({}, data), { userId: Request.channelHttp.getUserId() }) });
    }
    /** 一键删除 删除全部已读邮件 */
    deleteAllReadedMails() {
        return Request.channelHttp.http({ url: '/mail/user/v1/mails:one_click_delete', data: { userId: Request.channelHttp.getUserId() } });
    }
    /** 通过邮件ID领取邮件奖励
     * @param data.mailId 批量领取所需的邮件Id数组
     */
    getMailsAwardsByIds(data) {
        return Request.channelHttp.http({ url: '/mail/user/v1/mails:batch_receive', data: Object.assign(Object.assign({}, data), { userId: Request.channelHttp.getUserId() }) });
    }
    /** 一键领取 领取全部邮件奖励 */
    getAllMailsAwards() {
        return Request.channelHttp.http({ url: '/mail/user/v1/mails:one_click_receive', data: { userId: Request.channelHttp.getUserId() } });
    }
}

class MailUser extends MailUserApi {
    constructor() {
        super();
    }
}
const mailUser = new MailUser();

class PlayMallApi {
    /** 商城列表
     * @param data.mallId 商城id
     * @param data.page 页码
     * @param data.pageSize 页数
     * @param data.isNeedLimitTimeGoods 是否需要查询限时的商品
     */
    getList(data) {
        return Request.channelHttp.http({ url: '/mall/user/v1/goods/list', data });
    }
    /** 兑换商品
     * @param data.mallGoodsId 兑换id
     */
    exchangeAwards(data) {
        return Request.channelHttp.http({ url: '/mall/user/v1/goods/buy', data });
    }
}

class PlayMall extends PlayMallApi {
    constructor() {
        super();
    }
}
const playMall = new PlayMall();

class RankApi {
    /** 排行榜相关接口
    * @param data.rankId  排行榜id 如果不传，返回第一个榜单信息
    * @param data.page 指定页数
    * @param data.pageSize 单页条数
    * @param data.rankPeriodId 榜单周期id
    */
    getList(data) {
        return Request.channelHttp.http({ url: '/rank/user/v1/userListRankRecord', data });
    }
}

class Rank extends RankApi {
    constructor() {
        super();
    }
}
const rank = new Rank();

class ShareApi {
    /** 分享系统 取回超时未领取的奖励 */
    getShareTimeOutBackAward() {
        return Request.channelHttp.http({ url: '/share/user/v1/backTimeOutGiveItem' });
    }
    /** 分享系统 获取阶梯分享奖励配置
     *  @param data.shareId 分享配置id
    */
    getStageShare(data) {
        return Request.channelHttp.http({ url: '/share/user/v1/getStageShare', data });
    }
    /** 分享系统 获取假分享配置数据
     * @param data.shareId 分享配置id
     */
    getFakeShare(data) {
        return Request.channelHttp.http({ url: '/share/user/v1/getFakeShare', data });
    }
    /** 分享系统 获取赠送分享配置信息 ( 有哪些道具 可以分享 分享规则、配置图等 ) */
    getGiveShare() {
        return Request.channelHttp.http({ url: '/share/user/v1/getGiveShare' });
    }
    /** 分享系统 用户调用赠送接口 将道具赠送给其他用户
     * @param data.itemId 道具id
     * @param data.shareId 分享配置id
     */
    giveItem(data) {
        return Request.channelHttp.http({ url: '/share/user/v1/giveItem', data });
    }
    /** 分享系统 用户领取其他用户赠送的道具
     * @param data.giveItemKey 赠送道具生成的 key (分享口令)
     */
    takeGiveItem(data) {
        return Request.channelHttp.http({ url: '/share/user/v1/takeGiveItem', data });
    }
    /** 分享系统 用户上报假分享
     * @param data.shareId 分享配置id
    */
    uploadShareFakeShare(data) {
        return Request.channelHttp.http({ url: '/share/user/v1/uploadShareFakeShare', data });
    }
    /** shareHelp 型 阶梯分析 被邀请者上报助力
     * @param data.inviteRoleId 邀请者id
     * @param data.shareId 分享配置id
     */
    uploadHelpStageShare(data) {
        return Request.channelHttp.http({ url: '/share/user/v1/uploadHelpStageShare', data });
    }
    /** shareInvite 型 阶梯分享 用户分享后上报
     * @param data.shareId 分享配置id
    */
    uploadShareStageShare(data) {
        return Request.channelHttp.http({ url: '/share/user/v1/uploadShareStageShare', data });
    }
}

class Share extends ShareApi {
    constructor() {
        super();
    }
}
const share = new Share();

class SignInApi {
    /** 进行补签接口 是否直接发放补签奖励
    * @param data.fillTime  补签日期
    */
    fillSignIn(data) {
        return Request.channelHttp.http({ url: '/sign/user/v1/fillSignIn', data: Object.assign({ userId: Request.channelHttp.getUserId() }, data) });
    }
    /** 加载签到页数据 */
    getList() {
        return Request.channelHttp.http({ url: '/sign/user/v1/list', data: { userId: Request.channelHttp.getUserId() } });
    }
    /** 进行签到接口 当天签到奖励直接领取 */
    signIn() {
        return Request.channelHttp.http({ url: '/sign/user/v1/signIn', data: { userId: Request.channelHttp.getUserId() } });
    }
    /** 手动领取签到奖励接口 针对 连续签到/累计签到的奖励  需要单独领取
     * @param signType 签到类型
     */
    getAwards(data) {
        return Request.channelHttp.http({ url: '/sign/user/v1/getAwards', data: Object.assign({ userId: Request.channelHttp.getUserId() }, data) });
    }
}

class SignIn extends SignInApi {
    constructor() {
        super();
    }
}
const signIn = new SignIn();

class UltimatePrizeApi {
    /** 获取终极大奖配置接口 */
    getList() {
        return Request.channelHttp.http({ url: '/prize/user/v1/userAwardList', data: { userId: Request.channelHttp.getUserId() } });
    }
    /** 修改终极大奖
     * @param data.id 奖品id
     * @param data.settingId 配置id
     * @param data.action 换奖操作类型  ZHU_DONG BEI_DONG
     */
    changeTarget(data) {
        return Request.channelHttp.http({ url: '/prize/user/v1/changeTarget', data: Object.assign({ userId: Request.channelHttp.getUserId() }, data) });
    }
    /** 首次选择终极大奖
     * @param data.id 奖品id
     * @param data.settingId 配置信息id
     */
    confirmTarget(data) {
        return Request.channelHttp.http({ url: '/prize/user/v1/confirmTarget', data: Object.assign({ userId: Request.channelHttp.getUserId() }, data) });
    }
    /** 领取终极大奖奖励
     * @param data.settingId 配置信息id
     */
    getAward(data) {
        return Request.channelHttp.http({ url: '/prize/user/v1/getAward', data: Object.assign({ userId: Request.channelHttp.getUserId() }, data) });
    }
    /** 清空终极大奖奖励
     * @param data.settingId 配置信息id
     */
    cleanTarget(data) {
        return Request.channelHttp.http({ url: '/prize/user/v1/cleanTarget', data: Object.assign({ userId: Request.channelHttp.getUserId() }, data) });
    }
}

class UltimatePrize extends UltimatePrizeApi {
    constructor() {
        super();
    }
}
const ultimatePrize = new UltimatePrize();

class PlatformApi {
    constructor() {
        /** 活动信息 */
        this.active = active;
        /** 埋点 */
        this.additional = additional;
        /** 广告 */
        this.advert = advert;
        /** 权益背包 */
        this.benefit = benefit;
        /** 渠道通用 */
        this.channel = channel;
        /** 集卡/拼图 */
        this.fragment = fragment;
        /** 好友系统 */
        this.friend = friend;
        /** 道具 */
        this.item = item;
        /** 抽奖 */
        this.luckyDraw = luckyDraw;
        /** 邮件 */
        this.mailUser = mailUser;
        /** 商城玩法。活动下可以创建多个商城。每个商城下可以创建多个商品提供兑换。 */
        this.playMall = playMall;
        /** 排行榜玩法。活动下可以创建多个排行榜，不同的排行榜没有关联，排行榜上的分数是使用方（服务端）通过接口上报的。 */
        this.rank = rank;
        /** 分享 */
        this.share = share;
        /** 签到 */
        this.signIn = signIn;
        /** 任务 */
        this.task = task;
        /** 终极大奖 */
        this.ultimatePrize = ultimatePrize;
    }
}

exports.PlatformApi = PlatformApi;
exports.Request = Request;
exports.appid = appid;
exports.getConfig = getConfig;
exports.handleHerfParams = handleHerfParams;
