declare class Active extends ActiveApi {
    constructor() {
        super()
    }

}

declare class ActiveApi {
    /** 查询活动的基本信息 */
    public getDetails() {
        return Request.channelHttp.http<IMX_ActiveBaseConfig>({ url: '/active/user/v1/get' })
    }
}

declare class Additional extends ActiveApi {
    constructor() {
        super()
    }

}

declare class Advert extends AdvertApi {
    constructor() {
        super()
    }

}

declare class AdvertApi {
    /** 获取当前活动下的 广告投放 配置信息
     * @param data.eStatus 当前营销能力状态  unknow: 未知 - running: 投放中 - finish: 已结束 - wait: 待投放 - pause: 取消投放
     * @param data.sId 投放组id
     * @param data.sPos 投放位置
     * @param data.iBeginTime 开始时间
     * @param data.iEndTime 结束时间
     * @param data.page 所处页面数   
     * @param data.pageSize 单页数据条数
     */
    public getList(data: { eStatus?: string, sId?: string, sPos?: string, iBeginTime?: number, iEndTime?: number, page?: number, pageSize?: number }) {
        return Request.channelHttp.http({ url: '/advert/user/v1/output/list', data })
    }
}

export declare const appid = 'miaojie';

declare class Benefit extends BenefitApi {
    constructor() {
        super()
    }

}

declare class BenefitApi {
    /** C 端查询用户获得的奖励
     * @param {string} data.sId codeId （可以使用sCode单独查询）
     */
    public getList(data?: { sId?: string }) {
        return Request.channelHttp.http<IMX_AwardsBagInfo>({ url: '/benefit/user/v1/queryuserlist', data })
    }
    /** 用户填写地址
     * @param {IMX_InputUserAddrInfo} data 地址信息
     */
    public fillAddr(data: IMX_InputUserAddrInfo) {
        return Request.channelHttp.http({ url: '/benefit/user/v1/filladdr', data })
    }
    /** 填写直充账号
     * @param {string} data.account 用户直充账号
     */
    public fillAccount(data: { account: string }) {
        return Request.channelHttp.http({ url: '/benefit/user/v1/fillAccount', data })
    }
    /** 失效奖励,1.先不关注返还第三方的,2.总量加一
     * @param {string} data.sId
     */
    public usedCode(data: { sId: string }) {
        return Request.channelHttp.http<IMX_UseAwardCodeInfo>({ url: '/benefit/user/v1/usedcode', data: { sId: data.sId, eSuccess: "succ", } })
    }
}

declare class Channel extends ChannelApi {
    constructor() {
        super()
    }

}

declare class ChannelApi {
    /** 生成短链接
     * @param {string} data.longUrl
     */
    public gen(data: { longUrl?: string }) {
        return Request.channelHttp.http<{ code: number, msg: string, data: string }>({ url: '/channel/user/v1/shorturl/gen', data })
    }

    /** 解析短链接
     * @param {string} data.hashcode 短链接hashcode
     */
    public get(data: { hashcode?: string }) {
        return Request.channelHttp.http<{ code: number, msg: string, data: string }>({ url: '/channel/user/v1/shorturl/get', data })
    }

    /** 渠道订单能力，提供第三方订单查询能力
     * @param {RequestOrderType} data
     */
    public getOrderList<T = any>(data: RequestOrderType) {
        return Request.channelHttp.http<T>({ url: '/channel/user/v1/order/list', data })
    }
}

export declare type ChannelHttp = {
    /** 保存当前Axios实例对象 */
    http<T = any>(optons: { data?: any, url: string }): Promise<T>;
    /** 获取用户id */
    getUserId(): any;
}

declare type Config={
    	baseUrl:string
    	encode:boolean
}

/** 任务/成就分组类型 */
export declare enum EMX_TaskGroup {
    /** 常规任务组 */
    TASK = 1,
    /** 成就任务组 */
    ACHIEVEMENT = 2,
    /** 终极大奖成就任务 */
    FINALAWARDTASK = 3,
}

export declare type Env= 'dev'|'test'|'pre'|'online'

declare class Fragment extends FragmentApi {
    constructor() {
        super()
    }

}

declare class FragmentApi {
    /** 集卡/拼图 领奖 
     * @param data.settingId: 玩法配置id
     * @param data.id: 集字玩法 - 需要传入需要领取的 奖励主键id   拼图不需要
     * @param data.items 集字玩法 使用任意类型碎片兑换 , 需要传此参数 含 itemId itemCount
     */
    public getAwards(data: { settingId: string, id?: string, items?: IMX_CollectCardsItemsLitInfo[] }) {
        return Request.channelHttp.http<IMX_CollectCardsGetAwardsInfo>({ url: '/fragment/user/v1/getAwards', data: { ...data, userId: Request.channelHttp.getUserId() } })
    }

    /** 集卡/拼图 列表 
     * @param data.showLocation: 展示位置
     */
    public getList(data: { showLocation: string }) {
        return Request.channelHttp.http<IMX_CollectCardsInfo>({ url: '/fragment/user/v1/userAwardList', data: { ...data, userId: Request.channelHttp.getUserId() } })
    }
}

declare class Friend extends FriendApi {
    constructor() {
        super()
    }

}

declare class FriendApi {
    /** 好友系统 添加到黑名单
     * @param data.targetId 需要拉黑的目标用户id
     */
    public addBlacklist(data: { targetId: string }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/friends/user/v1/addBlacklist', data: { ...data, gameId: Request.channelHttp.getUserId() } })
    }

    /** 好友系统 通过ID请求添加好友
     * @param data.targetId 需要申请好友的目标用户id
     */
    public addFriendApply(data: { targetId: string }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/friends/user/v1/addFriendApply', data: { ...data, gameId: Request.channelHttp.getUserId() } })
    }

    /** 好友系统 处理好友申请请求 
     * @param data.targetId 处理好友申请请求 的目标用户id
     * @param data.agree 是否同意好友请求
     */
    public dealFriendApply(data: { targetId: string, agree: boolean }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/friends/user/v1/dealFriendApply', data: { ...data, gameId: Request.channelHttp.getUserId() } })
    }

    /** 好友系统 从黑名单中移出
     * @param data.targetId 目标用户id
     */
    public deleteBlacklist(data: { targetId: string }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/friends/user/v1/deleteBlacklist', data: { ...data, gameId: Request.channelHttp.getUserId() } })
    }

    /** 好友系统 删除好友
     * @param data.targetId 目标用户id
     */
    public deleteFriend(data: { targetId: string }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/friends/user/v1/deleteFriend', data: { ...data, gameId: Request.channelHttp.getUserId() } })
    }

    /** 好友系统 通过id查询个人详细信息
     * @param data.targetId 目标用户id
     */
    public getPlayerInfo(data: { targetId: string }) {
        return Request.channelHttp.http<IMX_FriendSysGetPlayerInfoById>({ url: '/friends/user/v1/getPlayerInfo', data: { ...data, gameId: Request.channelHttp.getUserId() } })
    }

    /** 好友系统 获取黑名单列表 */
    public getBlackList() {
        return Request.channelHttp.http<IMX_FriendSysBlackList>({ url: '/friends/user/v1/queryBlacklist', data: { gameId: Request.channelHttp.getUserId() } })
    }

    /** 好友系统 获取好友申请列表 */
    public getFriendsList() {
        return Request.channelHttp.http<IMX_FriendsListInfo>({ url: '/friends/user/v1/queryFriends', data: { gameId: Request.channelHttp.getUserId() } })
    }

    /** 好友系统 获取随机推举好友
     * @param data.num 目标用户id
     * @param data.preList 上次推举的好友id数组
     */
    public getRecommendFriends(data: { num: number, preList: string[] }) {
        return Request.channelHttp.http<IMX_FriendsListInfo>({ url: '/friends/user/v1/randomRecommend', data: { ...data, gameId: Request.channelHttp.getUserId() } })
    }

    /** 好友系统 生成好友申请key (生成名片)  */
    public buildBusinessCard() {
        return Request.channelHttp.http<IMX_FriendSysCardInfo>({ url: '/friends/user/v1/buildBusinessCard', data: { gameId: Request.channelHttp.getUserId() } })
    }

    /** 好友系统 使用好友key (使用名片) 
     * @param data.card 发送用户的名片
     */
    public useBusinessCard(data: { card?: string }) {
        return Request.channelHttp.http<IMX_FriendSysCardInfo>({ url: '/friends/user/v1/useBusinessCard', data: { gameId: Request.channelHttp.getUserId(), ...data } })
    }

    /** 更新个人信息  一般C端不需要调用此接口 由游戏服更新  */
    public updatePlayerInfo(data: IMX_FriendInfoItem) {
        return Request.channelHttp.http<IMX_FriendSysCardInfo>({ url: '/friends/user/v1/updatePlayerInfo', data: { ...data, gameId: Request.channelHttp.getUserId() } })
    }
}

export declare function getConfig(env: Env):Config {
    	const config = {
        		baseUrl: 'https://hserver.moxigame.cn/istio/grpc-gate/',
        		encode: false,
        	}

    	switch (env) {
        		case 'dev': // 开发
        			config.baseUrl = 'https://k8s-dev.moxigame.top/istio/grpc-gate/'
        			config.encode = false
        			break
        		case 'test': // 测试
        			config.baseUrl = 'https://sandbox.platform.moxigame.cn/k8s-test/istio/grpc-gate/'
        			config.encode = false
        			break
        		case 'pre': // 预发
        			config.baseUrl = 'https://sandbox.platform.moxigame.cn/k8s-pre/istio/grpc-gate/'
        			config.encode = false
        			break

        		: // 正式
        			break
        	}
    	return config
}

export declare const handleHerfParams:URLSearchParams = new URL(location.href).searchParams;

/** 活动基础配置信息 */
declare interface IMX_ActiveBaseConfig extends IMX_RequestNGBase {
    /** 活动id */
    sActiveId: string,
    /** 活动状态   (活动状态 haveNotStarted(ActiveMessage.活动未开始), inProgress(ActiveMessage.活动进行中), hasEnded(ActiveMessage.活动已结束), offShelfed(ActiveMessage.活动已下架)) */
    status: "haveNotStarted" | "inProgress" | "hasEnded" | "offShelfed",
    /** 活动标题 */
    title: string,
    /** 应用id */
    appId: string,
    /** 活动开始时间 */
    startTime: number,
    /** 活动结束时间 */
    endTime: number,
    /** 权益截止领取时间 */
    benefitGetEndTime: number,
    /** 活动创建时间 */
    createTime: number,
    /** 内容id */
    metaId: number,
    /** 活动名称 */
    name: string,
    /** 活动规则 (文本) */
    ruleText: string,
    /** 活动规则 (图片) */
    rulePic: string,
    /** 标签  多个时 以,隔开 */
    sTags: string,
    /** 游戏自定义透传字段 */
    customField: string,
}

/** 获奖记录/背包 item内容 */
declare interface IMX_AwardsBagAllInfoItem {
    /** 奖励相关信息 */
    mInfo: {
        /** 用户地址信息 */
        address?: IMX_UserAddrInfo,
        /** 填写地址时间 */
        iAddressTime?: number,
        /** 获得时间 */
        iCreateTime: number,
        /** 过期时间 */
        benefitGetEndTime: number,
        /** 状态 是否移出  0:未知状态  1:已删除  2:已获得  3：Used 已使用  */
        iStatus: number,
        /** 活动id */
        sActiveId: string,
        /** 券id */
        sId: string,

        /** 实物奖励 物流信息 物流单号 */
        sBillNo?: string,
        /** 第三方奖品 code  (兑换码)  json字符串
         *  不同奖励对应的内容不同 
         */
        sOutInfos?: string,
        /** 奖池id */
        sPoolId: string,
        /** 用户id */
        sUserId: string,

        /** 实物奖励 物流信息 物流企业名称 */
        sCorpName?: string,
        /** C端不需要处理的字段 */
        iProperty?: number[],

        /** 游戏层有需要的话自行定制  玩法类型  task:任务  prize:终极大奖  rank:排行榜   play:兑换商城  draw:抽奖  sign:抽奖   share:分享   */
        sPlay: "task" | "play" | "prize" | "rank" | "draw" | "sign" | "share",
        /** 玩法id */
        sPlayId: string,

        /** 二次封装 第三方外部信息 一般提供给非实物类奖励使用 */
        FZ_outInfoExtra?: {
            /** 卡密 卡号 */
            code?: string,
            /** 卡密 密码 */
            pwd?: string,
            /** 链接 链接信息 */
            link?: string,
            /** 直冲 */
            orderId?: string,
            /** 开始时间 */
            validStartTime?: number,
            /** 过期时间 */
            validEndTime?: number,
        },
    },

    /** 奖励配置信息 */
    mShow: {
        /** 实物奖励领取方式   领奖方式 1：邮寄， 2：联系客服，3：线下核销 */
        drawType: number,
        /** 联系方式说明类型 0:文本 1:图片 */
        contactType: number,
        /** 联系方式内容 图片链接或文本说明 */
        contactContent: string,
        /** 跳转链接 */
        contentLink: string,
        /** 奖励来源类型  绝大部分为 channel  EMX_PrizeSourceType */
        eSourceType: "input" | "system" | "channel",
        /** 奖池类型 sAwardType 在 channel 模式下  "1":卡密  "2":"链接"  "3":"实物"  "4":"直冲"  "5":"优惠券"  "6":"虚拟兑换码"  */
        sAwardType: string,
        /** 奖品详情类型 0:文本  1:图片 */
        FZ_sDetailType: 0 | 1,
        /** 奖品详情 */
        sDetail: string,
        /** 奖品名称 */
        sName: string,
        /** 奖品图 */
        sPicUrl: string,
    }

    current?: number,
    limit?: number,
    totalPage?: number,
    totalSize?: number,

}

/** 获奖记录/背包数据 */
declare interface IMX_AwardsBagInfo extends IMX_RequestNGBase {
    amInfos: IMX_AwardsBagAllInfoItem[],
    current?: number,
    limit?: number,
    totalPage?: number,
    totalSize?: number,
}

/** 分享赠送系统 检查并退还超时未领取的奖励 */
declare interface IMX_BackTimeOutGiveItems extends IMX_RequestNGBase {
    /** 是否有返还过期道具 */
    isReturnTimeoutItem: boolean,
}

/** 基础奖励信息 */
declare interface IMX_BaseAwardInfoItem {
    /** 奖品名称 */
    awardName: string,
    /** 奖励类型 */
    awardType: "item" | "benefit",
}

/** 基础奖励信息 */
declare interface IMX_BaseAwardInfoItem_2 {
    /** 奖品名称 */
    awardName: string,
    /** 奖励类型 */
    awardType: "item" | "benefit",
}

/** 集卡/拼图 奖励配置信息 */
declare interface IMX_CollectCardsAwardsConfigItem {
    /** 主键 */
    id: string,
    /** awardId */
    awardId: string,
    /** 奖励类型 */
    awardType: string,
    /** 奖品数量 */
    awardCount: string,
    /** 奖品名称 */
    awardName: string,
    /** 奖品图 */
    awardImage: string,
    /** 奖励价值 */
    awardPrice: number,

    /** 标签 */
    tag: string,
    /** 集字  指定类型碎片:ZHI_DING, 任意不同类型碎片:REN_YI_BU_TONG, ZHI_DING:  */
    exchangeType?: "ZHI_DING" | "REN_YI_BU_TONG" | "ZHI_DING",
    /** 集字 指定类型碎片兑换，道具配置 */
    exchangeItems?: IMX_CollectCardsItemsLitInfo[],
    /** 集字 其他兑换方式所需碎片数量  */
    exchangeLimit?: number,
    /** 当前领奖励是否可领取 (包含库存不足、领取上限等) */
    canGet: boolean,

    /** 奖品库存类型 */
    awardLimitType: string,
    /** 库存总量 */
    awardTotalNum: string,
    /** 此奖品已发放总量 */
    awardGotNum: string,

}

/** 集卡/拼图 兑换奖励成功返回信息 */
declare interface IMX_CollectCardsGetAwardsInfo extends IMX_RequestNGBase {
    awards: {
        /** 奖励名称 */
        awardName: string,
        /** 奖励图 */
        awardImage: string,
        /** 奖励id */
        awardId: string,
        /** 奖励数量 */
        awardCount: number,
        /** 奖励类型 */
        awardType: number,
        /** 奖励价值 */
    }[],
}

declare interface IMX_CollectCardsInfo extends IMX_RequestNGBase {
    /** 配置数据 */
    data: IMX_CollectCardsInfoItem[],

}

declare interface IMX_CollectCardsInfoItem {
    /** 配置id setting id */
    id: string,
    /** 玩法类型/使用场景 拼图玩法 集卡玩法   PIN_TU:拼图  JI_ZI:集卡   */
    useScene: "PIN_TU" | "JI_ZI",
    /** 配置名称 */
    name: string,
    /** 玩法开始时间 */
    startTime: number,
    /** 玩法结束时间 */
    endTime: number,
    /** C端多配置区分标记 */
    showLocation: string,
    /** 规则类型 */
    ruleType: string,
    /** 规则参数 */
    ruleValue: string,
    /** 透传字段 */
    reserveValue: string,
    /** 拼图数量 拆分格子数 */
    puzzleCount: number,
    /** 拼图效果图 */
    puzzleImage: string,
    /** 所需碎片道具 配置信息 */
    items: IMX_CollectCardsItemsConfig[],

    /** 奖励配置信息 */
    awards: IMX_CollectCardsAwardsConfigItem[],
}

/** 集卡/拼图 兑换成功 */
declare interface IMX_CollectCardsItemsConfig {
    /** 道具名称 */
    itemName: string,
    /** 道具图 */
    itemImage: string,
    /** 道具id */
    itemId: string,
    /** 用户已有道具数量 */
    userGotCount: number,
}

/** 集卡 所需道具数量信息 简要数据 */
declare interface IMX_CollectCardsItemsLitInfo {
    /** 道具id */
    itemId: string,
    /** 道具数量 */
    itemCount: number,
}

/** 兑换道具信息 */
declare interface IMX_ExchangeMoneyItems {
    /** 货币id */
    id: string,
    /** 道具名称 */
    name: string,
    /** 道具图标 */
    img: string,
    /** 道具数量 */
    count: number,
}

/** 兑换商城 完整数据 */
declare interface IMX_ExchangeShopInfo extends IMX_RequestNGBase {

    /** 兑换规则 */
    mallDesc: string,
    /** 兑换商城名称 */
    mallName: string,
    /** 兑换商城商品list */
    list: IMX_ExchangeShopInfoItem[],

    /** 二次封装 自己查询后 用户拥有的兑换道具 */
    FZ_myMoneys: IMX_ExchangeMoneyItems[],

    current?: number,
    limit?: number,
    totalPage?: number,
    totalSize?: number,
}

/** 兑换商城 item单项数据 */
declare interface IMX_ExchangeShopInfoItem {
    /** 奖品 商品id */
    mallGoodsId: string,
    /** 奖品名称 */
    awardName: string,
    /** 奖品图 */
    awardImg: string,
    /** 道具id  如果当前商品是道具  有此字段，供游戏内使用 */
    awardId?: string,
    /** 剩余库存 */
    awardLeftCount: number,
    /** 是否为无限库存商品  (道具奖励) */
    isAwardCountInfinite: boolean,
    /**  总库存 */
    awardCount?: number,
    /** 兑换所需道具信息 */
    moneys: IMX_ExchangeMoneyItems[],
    /**  后端当前是否达到限制  true 时无法购买  (与库存/货币数量无关)  */
    canReachBuyLimit: boolean,
    /** 描述文本 */
    desc?: string,
    onShelfStatus?: string,
    status?: string,
    userGetLimit?: number,
    limitOnShelfStartTime?: number,
    limitOnShelfEndTime?: number,
    dayGetLimit?: number,
    /** 游戏自定义透传字段 */
    customField: string,
    /** tags */
    tags: string[],
}

/** 终极大奖奖励配置信息 */
declare interface IMX_FinalAwardListInfo extends IMX_RequestNGBase {
    /** 奖励配置 */
    prizeAward: {
        /** 奖品集合 */
        awards: IMX_FinalAwardListInfoItem[],
        /**  剩余领奖次数  为0时  提示用户已结束  */
        canGetAwardCount: number,
        /** 当前选中奖品id */
        currentPrizeAwardId: string,
        /** 剩余兑换次数 */
        exchangePrizeCount: number,
        /** 配置id */
        id: string,
        /** 大奖名称 */
        name: string,
        /** 规则类型 */
        rules: "TEXT" | "IMAGE",
        /** 规则内容 */
        rulesValues: string,
        /** 使用场景 */
        scenes: "HUO_BI" | "CHENG_JIU",
        /** HUO_BI 当前已有的道具数量 */
        value: number,
        /** HUO_BI 道具名称 */
        useItemName: string,
        /** HUO_BI 道具图片 */
        useItemImage: string,
        /** HUO_BI 道具id */
        useItemId: string,
        /** 二次封装 当前完成进度  >=1 时 表示已完成目标 */
        FZ_currentProgress: number,

        /** 兑换奖励有效天数 */
        awardValidDay: number,
        /** 当前奖品选中时间 */
        currentPrizeAwardTime: number,
        /** 结束时间  */
        endTime: number,
        /** 游戏自定义透传字段 */
        reserveValue: string,

    }

}

/** 终极大奖奖励配置信息 item内容 */
declare interface IMX_FinalAwardListInfoItem {
    /** 奖品库存数量 */
    awardCount: number,
    /** 库存限制类型 unLimit不限制库存 */
    awardLimitType: string,
    /** 奖品 关联信息内id */
    awardId: string,
    /** 奖品图 */
    awardImage: string,
    /** 奖品名称 */
    awardName: string,
    /** 奖品类型 */
    awardType: string,
    /** 奖品id */
    id: string,
    /** 被动换奖继承  需扣除的数量  货币型 */
    passiveExtendsValue: number,
    /** 是否达到限制  true:已达到领取限制    false:未达到领取上限  */
    selected: boolean,
    /** 主动换奖继承  需扣除的数量  货币型 */
    takeExtendsValue: number,
    /** 目标值 */
    targetValue: number,
    /** 目标描述 成就型 */
    targetRemark: string,
    /** 任务id 成就型 */
    taskId: string,
    /** 额外自定义字段 tag */
    tag: string,

    /** 单人此奖品可领取次数上限 */

    /** 单人此奖品已领取次数 */

}

/** 好友系统单一用户信息 */
declare interface IMX_FriendInfoItem {
    /** 用户信息额外字段 */
    extra: any,
    /** 昵称 */
    nickname: string,
    /** 头像 */
    avatar: string,
    /** 用户id 预留字段 */
    FZ_id?: string,
}

/** 好友系统 好友列表 */
declare interface IMX_FriendsListInfo extends IMX_RequestNGBase {
    /** 用户ID obj形式 */
    infos: {
        /** 用户id */
        [propname: string]: IMX_FriendInfoItem,
    }

    /** 二次封装 用户数据 array形式  */
    FZ_infosList?: IMX_FriendInfoItem[],
}

/** 好友系统 获取黑名单 */
declare interface IMX_FriendSysBlackList extends IMX_RequestNGBase {
    /** 用户ID */
    infos: {
        /** 用户id */
        [propname: string]: IMX_FriendInfoItem,
    },

    /** 二次封装 用户数据 array形式  */
    FZ_infosList?: IMX_FriendInfoItem[],
}

/** 好友系统 生成好友名片信息 key */
declare interface IMX_FriendSysCardInfo extends IMX_RequestNGBase {
    /** 用户名片  (key) */
    card: string,
}

declare interface IMX_FriendSysGetPlayerInfoById extends IMX_RequestNGBase {
    /** 用户详细信息 */
    info: {
        /** 拓展字段 */
        extra: any,
        /** 昵称 */
        nickname: string,
        /** 头像 */
        avatar: string,
        /** 额外好友数量上限 */
        extraFriendNum: number,

    }
}

/** 游戏背包接口完整数据 */
declare interface IMX_GameItemsBagInfo extends IMX_RequestNGBase {
    /** 背包数据 */
    mInfo: IMX_GameItemsBagInfoItem[],
}

/** 游戏背包相关接口 item数据 */
declare interface IMX_GameItemsBagInfoItem {
    /** 道具数量 */
    iCount: number,
    /**  过期时间 */
    iEndTime: number,
    /** 获取时间 */
    iGetTime: number,
    /** 活动id */
    sActiveId: string,
    /** 道具数量限制类型 */
    sCountType: string,
    /** 道具图片 */
    sIcon: string,
    /** 唯一id */
    sId: string,
    /** 道具id */
    sItemId: string,
    /** 道具名称 */
    sName: string,
    /** 道具类型 */
    sType: string,
    /** 用户id */
    sUserId: string,
    /** 标签 */
    tag: string,
    /** 道具属性配置参数  
     *  PACK_NOT_SHOW("背包不显示", 2), USE_GAME("使用即通知游戏", 12);  注: 礼包类型特殊 不配置任何属性也可以使用
     */
    iProperty?: number[],
    /** 二次封装  当前道具是否可在背包内使用 */
    FZ_canUse: boolean,
    /** 二次封装  是否在游戏道具背包内展示 */
    FZ_ShowInBag?: boolean,
    /** 游戏自定义透传字段 */
    reserveValue: string,

}

/** 领取终极大奖返回信息 */
declare interface IMX_GetFinalAwardInfo extends IMX_RequestNGBase {
    /** 奖励信息 */
    awardInfo: {
        /** 奖励数量 */
        awardCount: number,
        /** 奖品图 */
        awardImage: string,
        /** 奖品名称 */
        awardName: string,
        /** 奖品类型 */
        awardType: "item" | "benefit",
    }[]
}

/** 领取其他用户赠送的道具 */

declare interface IMX_GetOtherGiveItemsAward extends IMX_RequestNGBase {
    /** 道具id */
    itemId: string,
    /** 领取奖励数量 */
    itemSendCount: number,
    /** 道具名称 */
    itemName: string,
    /** 道具图 */
    itemImg: string,
    /** 赠送者id */
    giveRoleId: string,
    /** 赠送者昵称 */
    giveRoleName: string,
}

/** 用户赠送道具 返回分享码信息 */
declare interface IMX_GiveItemsToOtherKeyInfo extends IMX_RequestNGBase {
    /** 赠送道具时生成的分享码 */
    giveItemKey: string,
}

/** 上报用户 奖品收货信息 */
declare interface IMX_InputUserAddrInfo extends IMX_UserAddrInfo {
    /** 奖品id */
    sId: string,
}

/** 一键领取全部邮件奖励 */
declare interface IMX_MailAwardsInfo extends IMX_RequestNGBase {
    /** 奖励列表 */
    mailAwards: IMX_MailAwardsInfoItem[],
}

/** 一键领取全部邮件奖励 Item */
declare interface IMX_MailAwardsInfoItem {
    /** 奖励ID */
    itemId: string,
    /** 奖励数量 */
    count: number,
    /** 奖励名称 */
    displayName: string,
    /** 奖励图片 */
    displayPic: string,
    /** 奖励领取状态 AWARD_GET_STATUS_SUCCESS:领取成功  AWARD_GET_STATUS_ERROR:领取失败  AWARD_GET_STATUS_UNSPECIFIED:默认未领取状态 */
    getStatus: "AWARD_GET_STATUS_SUCCESS" | "AWARD_GET_STATUS_ERROR" | "AWARD_GET_STATUS_UNSPECIFIED",
    /** 奖励领取时间 */
    getTimeStamp: number,
}

/** 获取邮件详情接口信息 */
declare interface IMX_MailDetailInfo {
    /** 邮件id */
    mailId: string,
    /** 邮件类型  系统通知型:MAIL_TYPE_SYS_NOTICE   好友邮件:MAIL_TYPE_PLAY_MAIL */
    mailType: "MAIL_TYPE_SYS_NOTICE" | "MAIL_TYPE_PLAY_MAIL",
    /** 发送者ID */
    ownerId: string,
    /** 标题 */
    title: string,
    /** 邮件内容 */
    content: string,
    /** 邮件奖励列表 */
    mailAwardList: IMX_MailAwardsInfoItem[],
    /** 邮件状态  已读:MAIL_STATUS_READ  未读:MAIL_STATUS_UNREAD  未知:MAIL_STATUS_UNSPECIFIED  */
    mailStatus: "MAIL_STATUS_UNSPECIFIED" | "MAIL_STATUS_READ" | "MAIL_STATUS_UNREAD",
    /** 邮件发送时间 */
    sendTimeStamp: number,
    /** 失效时间 */
    expiredTimeStamp: number,
}

declare interface IMX_MailDetailInfoReq extends IMX_RequestNGBase {
    /** 邮件详情信息 */
    mail: IMX_MailDetailInfo,
}

/** 用户邮件列表信息 */
declare interface IMX_MailsInfo {
    /** 邮件列表 */
    mailList: IMX_MailsInfoItem[],
    /** 是否还有下一页 */
    hasNext: boolean,
}

/** 用户邮件列表信息 Item */
declare interface IMX_MailsInfoItem {
    /** 邮件id */
    mailId: string,
    /** 邮件类型  系统通知型:MAIL_TYPE_SYS_NOTICE   好友邮件:MAIL_TYPE_PLAY_MAIL */
    mailType: "MAIL_TYPE_SYS_NOTICE" | "MAIL_TYPE_PLAY_MAIL",
    /** 发送者ID */
    ownerId: string,
    /** 标题 */
    title: string,
    /** 邮件内容 */
    content: string,
    /** 邮件奖励列表 */
    mailAwardList: IMX_MailAwardsInfoItem[],

    /** 邮件状态  已读:MAIL_STATUS_READ  未读:MAIL_STATUS_UNREAD  未知:MAIL_STATUS_UNSPECIFIED  */
    mailStatus: "MAIL_STATUS_UNSPECIFIED" | "MAIL_STATUS_READ" | "MAIL_STATUS_UNREAD",
    /** 邮件发送时间 */
    sendTimeStamp: number,
    /** 失效时间 */
    expiredTimeStamp: number,

    /** 奖励领取状态  -1:没奖励，0：有奖励但未领取，1：部分领取，2：全部领取  */
    awardReceiveStatus: number,

    /** 二次封装 邮件中是否有可领取的奖励 */
    FZ_canGetAwards: boolean,

    /** 二次封装 是否为新 在界面展示过之后 需修改此状态 */
    FZ_newTag: boolean,
}

/** 当前活动全部排行榜id/名称信息 */
declare interface IMX_RankAllListItem {
    /** 排行榜 */
    rankId: string,
    /** 排行榜名称 */
    name: string,
}

/** 排行榜奖品信息 */
declare interface IMX_RankAwardsListItem {
    /** 奖励id */
    awardId: string,
    /** 奖励价格 */
    awardPrice: number,
    /** 可获得的奖品数量 */
    awardCount: number,
    /** 奖品图 */
    awardImg: string,
    /** 奖品名称 */
    awardName: string,
    /** 奖品类型 */
    awardType: string,
    /** 奖品剩余库存 */
    awardLeftCount: number,
    /** 是否无限库存 */
    isAwardCountInfinite: boolean,

    /** 奖品起始名次 */
    rankStart: number,
    /** 奖品结束名次 */
    rankEnd: number,
}

/** 排行榜相关接口 */
declare interface IMX_RankInfo extends IMX_RequestNGBase {
    /** 当前排行榜配置信息 */
    curRankInfo: {
        /** 排行榜id */
        rankId: string,
        /** 排行榜名称 */
        name: string,
        /** 往期期数 */
        rankPeriodId: number, // = rankPeriodInfoList.id
        /** 开始时间 */
        startTime: number,
        /** 结束时间 */
        endTime: number,
        /** 是否已经发奖完成 已废弃
         * @deprecated
         */
        isOpenAwarded?: boolean,
        /** 当前榜单状态 haveNotStarted 未开始  inProgress 进行中  hasEnded 已结束  awarded已发奖  */
        status: "haveNotStarted" | "inProgress" | "hasEnded" | "awarded",
        /** 游戏自定义透传字段 */
        customField: string,
    }
    /** 所有排行榜id信息 */
    allRanks: IMX_RankAllListItem[]

    /** 排行榜 期数 配置信息List */
    rankPeriodInfo: IMX_RankPeriodInfoListItem[],
    /** 详细榜单信息 */
    rankRecordInfo: {
        /** 榜单当前页数 */
        page: number,
        /** 榜单 单页条数 */
        pageSize: number,
        /** 榜单总页数 */
        totalPage: number,
        /** 榜单总条数 */
        totalSize: number,
        rankRecord: IMX_RankRecordListItem[],

    },

    /** 当前玩家的信息 */
    roleRankInfo: IMX_RankRecordListItem,

    /** 排行榜奖品配置信息 */
    awards: IMX_RankAwardsListItem[],

}

/** 排行榜 期数 配置信息 单项item */
declare interface IMX_RankPeriodInfoListItem {
    /** 周期榜单id 查询其他周期榜单使用  id同时代表第几期 */
    id: number,
    /** 开始时间 */
    startTime: number,
    /** 结束时间 */
    endTime: number,
}

/** 排行榜主要排名信息  */
declare interface IMX_RankRecordListItem {
    /** 榜单排名 */
    rankIndex: number,
    /** 用户id */
    roleId: string,
    /** 用户分数 */
    score: number,
    /** 用户上榜时间 */
    onRankTime: number,
    /** 用户昵称 */
    nickName: string,
    /** 用户头像 */
    avatarUrl: string,
    /** 当前用户是否已经上榜 */
    isOnRank?: boolean,
    /** 当前用户是否被榜单拉黑 */
    isBlocked?: boolean,
}

/** 平台接口 基础返回值 请求处理结果 */
export declare interface IMX_RequestBase<T> {
    code: number,
    data?: T,
    serverTime?: number,
}

/** 平台接口 新网关返回值 */
export declare interface IMX_RequestNGBase {
    code: number,
    // mInfo?: T,
    serverTime?: number,
    /** 错误信息 */
    message?: string,
}

/** 分享奖励 基础配置信息 */
declare interface IMX_ShareAwardsBaseInfo {
    /** 奖品图 */
    awardImg: string,
    /** 奖励剩余数量 */
    awardLeftCount: number,
    /** 奖品名称 */
    awardName: string,
    /** 奖品价格 */
    awardPrice: number,
    /** 奖品库存数量是否无限 true:无限  false:有限 */
    isAwardCountInfinite: boolean,
    /** 分享奖励id */
    shareAwardId: string,
    /** 可获得数量 */
    shareAwardSendCount: number,
    /** 奖励类型 */
    shareAwardType: string,

    /** 分享次数  shareInvite 类配置生效  */
    shareCount?: number,
    /** 邀请成功次数  shareHelp 类配置生效 */
    helpProgressCount?: number,
}

/** 分享系统 分享阶梯奖励配置信息 */
declare interface IMX_ShareAwardsConfigInfo extends IMX_RequestNGBase {
    /** shareHelp 类 邀请者可获得的奖励配置 助力奖励配置信息 */
    helpConfigs: IMX_ShareAwardsBaseInfo[],
    /** shareHelp 类 可领取的助力奖励 */
    shareHelpAwardList: IMX_ShareAwardsBaseInfo[],
    /** shareHelp 类 当前已完成的助力进度 */
    helpProgressCount: number,

    /** 分享素材 */
    material: IMX_ShareConfigMaterialsItem[],
    /** 分享名称 */
    name: string,
    /** 分享规则类型 */
    ruleOption: "text" | "image",
    /** 分享规则图片列表 */
    rulePicUrls: string[],
    /** 分享规则文本 */
    ruleText: string,
    /** shareInvite 类 当前可领取的分享奖励 */
    shareAwardList: IMX_ShareAwardsBaseInfo[],
    /** shareInvite 类 分享邀请配置 */
    shareConfigs: IMX_ShareAwardsBaseInfo[],
    /** shareInvite 类 已分享次数 */
    shareCount: number,
    /** 阶梯分享类型  */
    type: "shareInvite" | "shareHelp",
    /** 游戏自定义透传字段 */
    customField: string,
    /** 发奖错误信息 此数组内的奖励发放失败 */
    errors: {
        /** 奖励id */
        awardId: string,
        /** 奖励类型 */
        awardType: string,
        /** 额外错误信息 */
        errorMessage: string,
    }[]
}

/** 分享系统  用户赠送配置信息 */
declare interface IMX_ShareCanShareItemsConfigInfo extends IMX_RequestNGBase {
    /** 可赠送的奖励列表 */
    giveItems: {
        /** 道具id */
        itemId: string,
        /** 单次赠送的数量 */
        itemSendCount: number,
    }[],
    /** 分享素材配置信息 */
    material: IMX_ShareConfigMaterialsItem[],
    /** 分享名称 */
    name: string,
    /** 分享规则类型 */
    ruleOption: "text" | "image",
    /** 分享规则图片列表 */
    rulePicUrls: string[],
    /** 分享规则文本 */
    ruleText: string,
}

/** 分享素材配置信息 */
declare interface IMX_ShareConfigMaterialsItem {
    /** 分享内容 */
    content: string,
    /** 分享标题 */
    title: string,
    /** 分享标签 */
    tag: string,
    /** 分享图 */
    picUrl: string,
}

/** 用户上报假分享 可获得的奖励 */
declare interface IMX_ShareFakeShareAwardsInfo extends IMX_RequestNGBase {
    /** 假分享获得的奖励 */
    shareAwardList: IMX_ShareAwardsBaseInfo[],
    /** 发奖错误信息 此数组内的奖励发放失败 */
    errors: {
        /** 奖励id */
        awardId: string,
        /** 奖励类型 */
        awardType: string,
        /** 额外错误信息 */
        errorMessage: string,
    }[],
}

/** 分享系统 获取假分享配置信息接口 数据 */
declare interface IMX_ShareFakeShareConfigInfo extends IMX_RequestNGBase {
    /** 假分享奖励配置 */
    fakeShareConfigs: IMX_ShareAwardsBaseInfo[],

    /** 是否达到假分享的限制次数 */
    isReachShareLimit: boolean,
    /** 分享素材配置信息 */
    material: IMX_ShareConfigMaterialsItem[],
    /** 分享名称 */
    name: string,
    /** 分享规则类型 */
    ruleOption: "text" | "image",
    /** 分享规则图片列表 */
    rulePicUrls: string[],
    /** 分享规则文本 */
    ruleText: string,
}

/** 签到后获奖信息  */
declare interface IMX_SignInAwardInfoItem extends IMX_BaseAwardInfoItem {
    /** 奖励数量 */
    awardCount: number,
    /** 奖励图 */
    awardImage: string,
}

/** 日期签到数据  */
declare interface IMX_SignInDateTypeInfo {
    /** 是否开启补签 活动配置信息 */
    fillSign: "OPEN" | "CLOSE",
    /** 奖励数据 */
    child: IMX_SignInInfoChildItem[],
    /** 签到配置id */
    signId: string,
    /** 签到类型 */
    signType: string,
    /** 日期签到类型 */
    dateSignType: string,
    /** 用户补签次数 */
    userFillSignCount: number,
    /** 最大可补签次数 */
    fillSignCountLimit: number,
    /** 当前天数 从0开始  */
    currentDay: number,
    /** 删除状态 是否展示 */
    deletedFlag: "SHOW" | "HIDE",
    /** 是否开启 后端用 C端不处理此字段 */
    status: boolean,
    /** 补签道具图 */
    fillSignItemIcon: string,
    /** 补签道具id */
    fillSignItemId: string,
    /** 补签道具名称 */
    fillSignItemName: string,
    /** 单次补签所需的道具数量 */
    fillSignItemCount: number,

    /** 本轮签到的起始时间戳 */
    refreshStartTime: number,

    /** 补签道具剩余数量  接口不返回，已通过查询道具获取  二次封装数据   */
    FZ_fillSignItemsCountNow: number,

    /** 游戏自定义透传字段 */
    reserveValue: string,

}

/** 获取签到数据 */
declare interface IMX_SignInInfo extends IMX_RequestNGBase {
    /** 日期签到数据 */
    dateSignAwards: IMX_SignInDateTypeInfo,

    /** 连续签到数据 */
    continuousSignAwards: IMX_SignInOtherTypeInfo,

    /** 累计签到模板 */
    cumulativeSignAwards: IMX_SignInOtherTypeInfo,

    /** 二次封装 签到页标题 */
    FZ_title: string,
    /** 二次封装 当天是否已签到 */
    FZ_currentDaySignIn: boolean,
    /** 二次封装 是否展示签到效果 */
    FZ_showSignInAni: boolean,
}

/** 签到数据接口 奖励item   就离谱 为什么用 one two 标记，不用数组包起来。没见过这样的   */
declare interface IMX_SignInInfoChildItem {
    /** 奖励序列 */
    id: string,
    /** 奖励所属模板组id */
    groupId: string,
    /** 奖励类型 */
    awardOneType: string,
    /** 奖励id */
    awardOneId: string,
    /** 奖励名称 */
    awardOneName: string,
    /** 奖励图 */
    awardOneImage: string,
    /** 奖励数量 */
    awardOneCount: number,
    /** 奖励类型 */
    awardTwoType?: string,
    /** 奖励id */
    awardTwoId?: string,
    /** 奖励名称 */
    awardTwoName?: string,
    /** 奖励图 */
    awardTwoImage?: string,
    /** 奖励数量 */
    awardTwoCount?: number,
    /** 日期 */
    day: number,
    /** 是否已签到 */
    sign: boolean,

    /** 二次封装字段 signIn:可签到  signIned:已签到且领取奖励  fillSignIn:可补签  willSignIn:未开启  noSignIn:未签到且不可补签  canGetAward:可领奖  */
    FZ_currentState: "signIn" | "signIned" | "fillSignIn" | "willSignIn" | "noSignIn" | "canGetAward",
}

/** 连续/累计签到数据 */
declare interface IMX_SignInOtherTypeInfo {
    /** 奖励数据 */
    child: IMX_SignInInfoChildItem[],
    /** 签到配置id */
    signId: string,
    /** 签到类型 */
    signType: string,
    /** 签到次数 */
    signCount: number,
    /** 上次签到时间 */
    lastSignTime: number,

    // LastSignDay:number, // 上次签到天数 暂不需要 
    /** 上次领奖天数 */
    awardDay: number,
    /** 删除状态 是否展示 */
    deletedFlag: "SHOW" | "HIDE",
    /** 是否开启 后端用 C端不处理此字段 */
    status: boolean,
    /** 当天是否已签到 */
    currentDaySignIn: boolean,


    /** 是否可领取奖励   二次封装数据 */
    FZ_canGetAwards: boolean,

    /** 游戏自定义透传字段 */
    reserveValue: string,
}

/** 用户签到接口返回信息 */
declare interface IMX_SignInResult extends IMX_RequestNGBase {
    /** 奖品列表 */
    list: IMX_SignInAwardInfoItem[],
    /** 发放奖励内容 */
    msg: string,
    /** 签到后的天数信息 */
    days: {
        type: string,
        signDay: number,
    }[],
}

/** 任务/成就完成可获得的奖励数据 */
declare interface IMX_TaskAwardsInfo extends IMX_RequestNGBase {
    /** 奖品列表   注: 如果是上报任务接口 只有配置 自动领取 且上报后发奖成功才会返回此奖励信息 */
    awards?: IMX_TaskAwardsInfoItem[],
}

/** 任务/成就完成可获得的奖励数据item */
declare interface IMX_TaskAwardsInfoItem extends IMX_BaseAwardInfoItem_2 {
    /** 获得奖励的数量 */
    awardGetCount: number,
    /** 奖励图 */
    awardImg: string,
    /** 奖品id */
    awardId?: string,
}

declare interface IMX_TaskInfo extends IMX_RequestNGBase {
    task: IMX_TaskInfoItem[],
}

/** 任务/成就item信息中 商品广告类型数据 */
declare interface IMX_TaskInfoAdsGoodsContent {
    /**商品id */
    id: string,
    /** 商品名称 */
    name: string,
    /** 商品图 */
    picUrl: string,
    /** 商品价格 */
    price: number,
    /** 是否已收藏 */
    collectState?: boolean,
}

/** 任务/成就列表item数据 */
declare interface IMX_TaskInfoItem {
    /** 任务id */
    taskId: string,
    /** 任务图标 */
    taskIcon: string,
    /** 任务状态  "unfinish"=未完成,"unGeted"=已完成未领取,"geted"=已领取  */
    status: "unfinish" | "unGeted" | "geted",
    /** 任务类型 */
    type: Number,
    /** 任务名称 */
    name: string,
    /** 任务描述 */
    desc: string,
    /** 任务刷新周期限制 */
    refreshCycles: {
        /** 当前刷新次数 */
        curRefreshValue: number,
        /** 任务刷新次数上限 */
        maxRefreshTimes: number,
        /** 刷新类型  (刷新类型 daily每日/weekly每周/month每月/total总的) */
        type: string,
    }[],
    /** 任务完成的进度 */
    currentValue: number,
    /** 任务完成条件 */
    targetValue: number,
    /** 任务奖励 */
    awards: {
        /** 奖励数量 */
        awardCount: number,
        /** 奖励图 */
        awardImg: string,
        /** 奖励名称 */
        awardName: string,
        /** 奖励类型 */
        awardType: "item" | "benefit",

    }[],
    /** 广告展示类型 没有广告none,单个广告sigle,广告列表list */
    advertShowStyle: "none" | "sigle" | "list",
    /** 广告列表 */
    ads: IMX_TaskInfoItemAdsItem[],
    /** 单个广告 */
    adInfo: IMX_TaskInfoItemAdsItem,
    /** 是否需要前端隐藏 */
    isNeedFrondHide: boolean,
    /** 游戏自定义透传字段 */
    customField: string,
}

/** 任务/成就item信息中携带的广告信息 */
declare interface IMX_TaskInfoItemAdsItem {
    /** 广告id */
    id: string,
    /** 广告名称 */
    name: string,
    /** 广告类型 "text"=文本广告,"picUrl"=图片广告,"singleGoods"=单个商品广告,"multiGoods"=商品列表广告,"skipParam"=跳转参数广告   multiGoods 已弃用   */
    type: "text" | "picUrl" | "singleGoods" | "multiGoods" | "skipParam",
    /** 文本广告内容 */
    textContent: string,
    /** 图片广告内容 图片链接 */
    picUrlContent: string[],
    /**  单个商品广告内容 */
    singleGoodsContent: IMX_TaskInfoAdsGoodsContent,
    /**@deprecated
     *  商品列表广告内容 */
    multiGoodsContentList: IMX_TaskInfoAdsGoodsContent[],
    /** 跳转类型广告 */
    skipParamContent: {
        key: string,
        /** 跳转目标  id或链接 */
        value: string,
    }[],
}

/** 被邀请者用户上报助力 可获得的奖励 */
declare interface IMX_UploadShareHelpAwardsInfo extends IMX_RequestNGBase {
    /** 奖励信息 */
    helpAwardList: IMX_UploadShareHelpAwardsInfoItem[],
    /** 发奖错误信息 此数组内的奖励发放失败 */
    errors: {
        /** 奖励id */
        awardId: string,
        /** 奖励类型 */
        awardType: string,
        /** 额外错误信息 */
        errorMessage: string,
    }[],

}

/** 被邀请者用户上报助力 可获得的奖励 item */
declare interface IMX_UploadShareHelpAwardsInfoItem {
    /** 助力用户标签 */
    helpRoleTag: string,
    /** 本标签用户助力完成进度配比 */
    helpProgressCount: number,
    /** 助力奖励id */
    helpAwardId: string,
    /** 助力奖励类型  */
    helpAwardType: string,
    /** 助力奖励发放数量 */
    helpAwardSendCount: number,
    /** 奖励名称 */
    awardName: string,
    /** 奖励图 */
    awardImg: string,
    /** 奖励价格 */
    awardPrice: number,
    /** 剩余奖励数量 */
    awardLeftCount: number,
    /** 是否为无限库存的 */
    isAwardCountInfinite: boolean,
}

/** 使用兑换码 获取第三方奖品信息  返回内容 */
declare interface IMX_UseAwardCodeInfo extends IMX_RequestNGBase {
    /** 第三方奖品 code  (兑换码) */
    sOutInfos: string,
    /** (奖池里面的具体的一个奖励编码 */
    sCodeId: string,
}

/** 用户地址内容 */
declare interface IMX_UserAddrInfo {
    /** 收件人 */
    sAddrName?: string,
    /** 收件人手机号 */
    sAddrTelNumber?: string,
    /** 详细地址 */
    sAddrDetailInfo?: string,
    /** 省份 */
    sAddrProvinceName?: string,
    /** 市 */
    sAddrCityName?: string,
    /** 区 */
    sAddrCountyName?: string,
    /** 邮政编码 */
    sAddrCityCode?: string,
}

declare class Item extends ItemApi {
    constructor() {
        super()
    }

}

declare class ItemApi {


    /** 获取游戏道具背包信息
     * @param data.sItemId: 道具id
     * @param data.bShow: 是否返回显示资源 默认不显示
     * @param data.bScore: 是否三方积分查询
     */
    public getList(data?: { sItemId?: string, bShow?: boolean, bScore?: boolean }) {
        return Request.channelHttp.http<IMX_GameItemsBagInfo>({ url: '/item/user/v1/userItemList', data: { ...data, sUserId: Request.channelHttp.getUserId() } })
    }

    /** 使用游戏道具
     * @param data.sItemId: 道具id
     * @param data.iCount: 使用道具数量
     * @param data.items 集字玩法 使用任意类型碎片兑换 , 需要传此参数 含 itemId itemCount
     */
    public useItem(data: { sItemId: string, iCount: number }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/item/user/v1/useItem', data: { ...data, sUserId: Request.channelHttp.getUserId() } })
    }

    /** 移动两个用户道具
     * @param data.sTargetUid: 目标用户ID
     * @param data.sTargetActiveId: 目标活动ID
     * @param data.sSourceUid 来源用户ID
     * @param data.sSourceActiveId 来源活动ID
     * @param data.mInfo 移动道具信息
     */
    public move(data: { sTargetUid: string, sTargetActiveId: string, sSourceUid: string, sSourceActiveId: string, mInfo: { sItemId: string, iCount: number, eMoveType: string }[] }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/item/user/v1/moveUserItem', data })
    }
}

declare class LuckyDraw extends ItemApi {
    constructor() {
        super()
    }

}

declare class MailUser extends MailUserApi {
    constructor() {
        super()
    }

}

declare class MailUserApi {
    /** 获取邮件列表
     * @param {number} data.page 当前页面数
     * @param {number} data.pageSize 单页条数
     */
    public getList(data: { page: number, pageSize: number }) {
        return Request.channelHttp.http<IMX_MailsInfo>({ url: '/mail/user/v1/mails:list', data: { ...data, userId: Request.channelHttp.getUserId() } })
    }

    /** 读取邮件详情
     * @param {string} data.mailId
     */
    public getDetail(data: { mailId: string }) {
        return Request.channelHttp.http<IMX_MailDetailInfoReq>({ url: '/mail/user/v1/mails:get', data: { ...data, userId: Request.channelHttp.getUserId() } })
    }

    /** 通过邮件id删除邮件
     * @param data.mailId
     */
    public deleteByMailIds(data: { mailId: string[] }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/mail/user/v1/mails:batch_delete', data: { ...data, userId: Request.channelHttp.getUserId() } })
    }

    /** 一键删除 删除全部已读邮件 */
    public deleteAllReadedMails() {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/mail/user/v1/mails:one_click_delete', data: { userId: Request.channelHttp.getUserId() } })
    }

    /** 通过邮件ID领取邮件奖励
     * @param data.mailId 批量领取所需的邮件Id数组
     */
    public getMailsAwardsByIds(data: { mailId: string[] }) {
        return Request.channelHttp.http<IMX_MailAwardsInfo>({ url: '/mail/user/v1/mails:batch_receive', data: { ...data, userId: Request.channelHttp.getUserId() } })
    }

    /** 一键领取 领取全部邮件奖励 */
    public getAllMailsAwards() {
        return Request.channelHttp.http<IMX_MailAwardsInfo>({ url: '/mail/user/v1/mails:one_click_receive', data: { userId: Request.channelHttp.getUserId() } })
    }
}

export declare namespace Navigate {

    export interface NavigateToOptions {
        /**
         * 需要跳转的页面路径 , 路径后可以带参数
         */
        url?: string;
        /** 中台跳转参数 */
        platformParams?: any;
        /** 接口调用成功的回调函数 */
        success?: (result: NavigateToSuccessOptions) => void;
        /**
         * 接口调用失败的回调函数
         */
        fail?: (result: any) => void;
        /**
         * 接口调用结束的回调函数（调用成功、失败都会执行）
         */
        complete?: (result: any) => void;
    }

    export interface NavigateToSuccessOptions {
        /**
         * 回调信息
         */
        errMsg: string;
    }
    /**
     * 跳转到应用内的某个页面
     */
    export type NavigateTo = (options: NavigateToOptions) => void

    export interface NavigateBackOptions {
        /**
         * 返回的页面数，如果 delta 大于现有页面数，则返回到首页
         */
        delta?: number;
        /**
         * 接口调用成功的回调函数
         */
        success?: (result: any) => void;
        /**
         * 接口调用失败的回调函数
         */
        fail?: (result: any) => void;
        /**
         * 接口调用结束的回调函数（调用成功、失败都会执行）
         */
        complete?: (result: any) => void;
    }

    /**
     * 返回上一页面或多级页面
     */
    export type NavigateBack = (options: NavigateBackOptions) => void
}

export declare class PlatformApi {
    /** 活动信息 */
    public active: Active = active

    /** 埋点 */
    public additional: Additional = additional

    /** 广告 */
    public advert: Advert = advert

    /** 权益背包 */
    public benefit: Benefit = benefit

    /** 渠道通用 */
    public channel: Channel = channel

    /** 集卡/拼图 */
    public fragment: Fragment = fragment

    /** 好友系统 */
    public friend: Friend = friend

    /** 道具 */
    public item: Item = item

    /** 抽奖 */
    public luckyDraw: LuckyDraw = luckyDraw

    /** 邮件 */
    public mailUser: MailUser = mailUser

    /** 商城玩法。活动下可以创建多个商城。每个商城下可以创建多个商品提供兑换。 */
    public playMall: PlayMall = playMall

    /** 排行榜玩法。活动下可以创建多个排行榜，不同的排行榜没有关联，排行榜上的分数是使用方（服务端）通过接口上报的。 */
    public rank: Rank = rank

    /** 分享 */
    public share: Share = share

    /** 签到 */
    public signIn: SignIn = signIn

    /** 任务 */
    public task: Task = task

    /** 终极大奖 */
    public ultimatePrize: UltimatePrize = ultimatePrize
}

declare class PlayMall extends PlayMallApi {
    constructor() {
        super()
    }

}

declare class PlayMallApi {
    /** 商城列表
     * @param data.mallId 商城id
     * @param data.page 页码
     * @param data.pageSize 页数
     * @param data.isNeedLimitTimeGoods 是否需要查询限时的商品
     */
    public getList(data: { mallId: string, page?: number, pageSize?: number, isNeedLimitTimeGoods?: boolean }) {
        return Request.channelHttp.http<IMX_ExchangeShopInfo>({ url: '/mall/user/v1/goods/list', data })
    }

    /** 兑换商品
     * @param data.mallGoodsId 兑换id
     */
    public exchangeAwards(data: { mallGoodsId: string }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/mall/user/v1/goods/buy', data })
    }
}

/**
 *  公共参数
 */
export declare interface PublicParams {
    [propName: string]: any
}

declare class Rank extends RankApi {
    constructor() {
        super()
    }

}

declare class RankApi {
    /** 排行榜相关接口
     * @param data.rankId  排行榜id 如果不传，返回第一个榜单信息
     * @param data.page 指定页数
     * @param data.pageSize 单页条数
     * @param data.rankPeriodId 榜单周期id
     */
    public getList(data?: { rankId?: string, page: number, pageSize: number, rankPeriodId?:number }) {
        return Request.channelHttp.http<IMX_RankInfo>({ url: '/rank/user/v1/userListRankRecord', data })
    }
}

declare class Request_2 {
    static publicParams: PublicParams = {};
    static Headers: object = {};
    static responseIntercept: (response: any) => any | undefined;
    static requestBefore: (config: any) => any;
    static errorCallback: (config: any) => any;
    static channelHttp: ChannelHttp
    /**
     * 设置公共参数 
     * @param publicParams an url as a string
     */
    public setPublicParams(publicParams: PublicParams): void {
        Request.publicParams = { ...Request.publicParams, ...publicParams };
    }
    /**
     * 删除公共参数的某一项
     * @param key an url as a string
     */
    public removePublicParams(key: string): void {
        delete Request.publicParams[key]
    }
    /**
     * 设置响应拦截器 
     */
    public setResponseIntercept<T = any>(callback: (config: T) => void): void {
        Request.responseIntercept = callback;
    }
    /**
     * 捕获异常处理 
     */
    public setErrorCallback<T = any>(callback: (config: T) => void): void {
        Request.errorCallback = callback;
    }
    /**
     * 请求之前干点啥 
     */
    public setRequestBefore<T = any>(callback: (config: T) => void): void {
        Request.requestBefore = callback;
    }
    /**
     * 设置请求头
     */
    public setHeaders(headers: object) {
        Request.Headers = headers;
    }
}
export { Request_2 as Request }

declare type RequestOrderType = {
    /** 对应的应用id （这里一个应用可能对应有多种不同的登录模式，待定细节） */
    appId: string,
    /** 渠道实际名字，特殊场景需要使用（比如一个应用选择了多选了多个不同的渠道，然后要做打通） */
    channelName?: string,
    /** 当前页数 */
    page?: number,
    /** 当前条数 */
    pageSize?: number,
    /** 用户ID */
    uid?: string,
    /** 订单创建时间-开始 */
    startTime?: number,
    /** 订单创建时间-结束 */
    endTime?: number,
    /** 订单状态 */
    orderStatus?: string,
}

declare class Share extends ShareApi {
    constructor() {
        super()
    }

}

declare class ShareApi {
    /** 分享系统 取回超时未领取的奖励 */
    public getShareTimeOutBackAward() {
        return Request.channelHttp.http<IMX_BackTimeOutGiveItems>({ url: '/share/user/v1/backTimeOutGiveItem' })
    }

    /** 分享系统 获取阶梯分享奖励配置
     *  @param data.shareId 分享配置id
     */
    public getStageShare(data: { shareId: string }) {
        return Request.channelHttp.http<IMX_ShareAwardsConfigInfo>({ url: '/share/user/v1/getStageShare', data })
    }

    /** 分享系统 获取假分享配置数据
     * @param data.shareId 分享配置id
     */
    public getFakeShare(data: { shareId: string }) {
        return Request.channelHttp.http<IMX_ShareFakeShareConfigInfo>({ url: '/share/user/v1/getFakeShare', data })
    }

    /** 分享系统 获取赠送分享配置信息 ( 有哪些道具 可以分享 分享规则、配置图等 ) */
    public getGiveShare() {
        return Request.channelHttp.http<IMX_ShareCanShareItemsConfigInfo>({ url: '/share/user/v1/getGiveShare' })
    }

    /** 分享系统 用户调用赠送接口 将道具赠送给其他用户
     * @param data.itemId 道具id
     * @param data.shareId 分享配置id
     */
    public giveItem(data: { itemId: string, shareId: string }) {
        return Request.channelHttp.http<IMX_GiveItemsToOtherKeyInfo>({ url: '/share/user/v1/giveItem', data })
    }

    /** 分享系统 用户领取其他用户赠送的道具
     * @param data.giveItemKey 赠送道具生成的 key (分享口令)
     */
    public takeGiveItem(data: { giveItemKey: string }) {
        return Request.channelHttp.http<IMX_GetOtherGiveItemsAward>({ url: '/share/user/v1/takeGiveItem', data })
    }

    /** 分享系统 用户上报假分享 
     * @param data.shareId 分享配置id
     */
    public uploadShareFakeShare(data: { shareId: string }) {
        return Request.channelHttp.http<IMX_ShareFakeShareAwardsInfo>({ url: '/share/user/v1/uploadShareFakeShare', data })
    }

    /** shareHelp 型 阶梯分析 被邀请者上报助力
     * @param data.inviteRoleId 邀请者id
     * @param data.shareId 分享配置id
     */
    public uploadHelpStageShare(data: { inviteRoleId: string, shareId: string }) {
        return Request.channelHttp.http<IMX_UploadShareHelpAwardsInfo>({ url: '/share/user/v1/uploadHelpStageShare', data })
    }

    /** shareInvite 型 阶梯分享 用户分享后上报 
     * @param data.shareId 分享配置id
     */
    public uploadShareStageShare(data: { shareId: string }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/share/user/v1/uploadShareStageShare', data })
    }
}

declare class SignIn extends SignInApi {
    constructor() {
        super()
    }

}

declare class SignInApi {
    /** 进行补签接口 是否直接发放补签奖励
     * @param data.fillTime  补签日期
     */
    public fillSignIn(data: { fillTime: number }) {
        return Request.channelHttp.http<IMX_SignInResult>({ url: '/sign/user/v1/fillSignIn', data: { userId: Request.channelHttp.getUserId(), ...data } })
    }

    /** 加载签到页数据 */
    public getList() {
        return Request.channelHttp.http<IMX_SignInInfo>({ url: '/sign/user/v1/list', data: { userId: Request.channelHttp.getUserId() } })
    }

    /** 进行签到接口 当天签到奖励直接领取 */
    public signIn() {
        return Request.channelHttp.http<IMX_SignInResult>({ url: '/sign/user/v1/signIn', data: { userId: Request.channelHttp.getUserId() } })
    }

    /** 手动领取签到奖励接口 针对 连续签到/累计签到的奖励  需要单独领取 
     * @param signType 签到类型
     */
    public getAwards(data: { signType: string }) {
        return Request.channelHttp.http<IMX_SignInResult>({ url: '/sign/user/v1/getAwards', data: { userId: Request.channelHttp.getUserId(), ...data } })
    }
}

declare class Task extends TaskApi {
    constructor() {
        super()
    }

}

declare class TaskApi {
    /** 用户任务列表
     * @param {string} data.groupId 任务分组 1=普通任务；2=成就任务；3=终极大奖成就任务
     * @returns 返回任务列表数据 
     */
    public getList(data?: { groupId?: string }) {
        return Request.channelHttp.http<IMX_TaskInfo>({ url: '/task/user/v1/list', data })
    }
    /** 完成任务领取奖励 
     * @param {string} data.taskId 任务ID
     */
    public getAwards(data: { taskId: string }) {
        return Request.channelHttp.http<IMX_TaskAwardsInfo>({ url: '/task/user/v1/finishTask', data })
    }
    /** 做任务 
     * @param {string} data.opType      任务操作类型 set/add/max
     * @param {number} data.opValue     任务操作值
     * @param {string} data.taskId      任务id
     * @param {string} data.judgeValue  区分相同类型任务
     * @param {string} data.groupId     任务分组 1=普通任务；2=成就任务；3=终极大奖成就任务
     * @param {string} data.adId        完成任务相关的广告id
     */
    public doEvent(data: { opType: 'set' | 'add' | 'max', opValue: number, taskId: string, judgeValue?: string, groupId?: string, adId?: string }) {
        return Request.channelHttp.http<IMX_TaskAwardsInfo>({ url: '/task/user/v1/doEventTask', data })
    }
}

declare class UltimatePrize extends UltimatePrizeApi {
    constructor() {
        super()
    }

}

declare class UltimatePrizeApi {
    /** 获取终极大奖配置接口 */
    public getList() {
        return Request.channelHttp.http<IMX_FinalAwardListInfo>({ url: '/prize/user/v1/userAwardList', data: { userId: Request.channelHttp.getUserId() } })
    }


    /** 修改终极大奖
     * @param data.id 奖品id
     * @param data.settingId 配置id
     * @param data.action 换奖操作类型  ZHU_DONG BEI_DONG
     */
    public changeTarget(data: { id: string, settingId: string, action: string }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/prize/user/v1/changeTarget', data: { userId: Request.channelHttp.getUserId(), ...data } })
    }

    /** 首次选择终极大奖
     * @param data.id 奖品id
     * @param data.settingId 配置信息id
     */
    public confirmTarget(data: { id: string, settingId: string }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/prize/user/v1/confirmTarget', data: { userId: Request.channelHttp.getUserId(), ...data } })
    }

    /** 领取终极大奖奖励
     * @param data.settingId 配置信息id
     */
    public getAward(data: { settingId: string }) {
        return Request.channelHttp.http<IMX_GetFinalAwardInfo>({ url: '/prize/user/v1/getAward', data: { userId: Request.channelHttp.getUserId(), ...data } })
    }

    /** 清空终极大奖奖励
     * @param data.settingId 配置信息id
     */
    public cleanTarget(data: { settingId: string }) {
        return Request.channelHttp.http<IMX_RequestNGBase>({ url: '/prize/user/v1/cleanTarget', data: { userId: Request.channelHttp.getUserId(), ...data } })
    }
}

export { }
